@@ -1,13 +1,14 @@
 import tensorflow
 
 from dbnd._core.errors import friendly_error
-from dbnd._vendor.cloudpickle import cloudpickle
+from dbnd._core.utils.seven import cloudpickle
+from dbnd_tensorflow.seven import History, models
 from targets import LocalFileSystem
 from targets.marshalling.marshaller import Marshaller
 
 
 class TensorflowKerasModelMarshaller(Marshaller):
-    type = tensorflow.keras.models.Model
+    type = models.Model
     support_directory_read = False
 
     _compression_read_arg = None
@@ -21,18 +22,18 @@ class TensorflowKerasModelMarshaller(Marshaller):
             raise friendly_error.targets.target_must_be_local_for_tensorflow_marshalling(
                 target
             )
-        model = tensorflow.keras.models.load_model(target.path, **kwargs)
+        model = models.load_model(target.path, **kwargs)
         return model
 
     def value_to_target(self, value, target, **kwargs):
-        tensorflow.keras.models.save_model(value, target.path, **kwargs)
+        models.save_model(value, target.path, **kwargs)
 
 
 class TensorflowKerasHistoryMarshaller(Marshaller):
-    type = tensorflow.python.keras.callbacks.History
+    type = History
 
     def target_to_value(self, target, **kwargs):
-        h = tensorflow.python.keras.callbacks.History()
+        h = History()
         with target.open("rb") as dumped:
             h.history = cloudpickle.load(dumped)
         return h
